==> contextly-7.x-2.0.tar.gz: contextly/js/contextly-node-view.js <==
(function ($) {

  Contextly.Settings = Contextly.createClass({

    extend: Contextly.BaseSettings,

    statics: {

      /**
       * @param key
       * @param [fallback]
       */
      getDrupalSetting: function(key, fallback) {
        if (!Drupal.settings.contextlyWidgets) {
          return fallback;
        }

        if (typeof Drupal.settings.contextlyWidgets[key] === 'undefined') {
          return fallback;
        }

        return Drupal.settings.contextlyWidgets[key];
      },

      getDrupalNodeUpdateUrl: function() {
        return this.getDrupalSetting('putNodeURL');
      },

      /**
       * Returns API server URL.
       *
       * @function
       */
      getAPIServerUrl: function() {
        return this.getDrupalSetting('apiServerURL');
      },

      /**
       * Returns main Contextly server URL.
       *
       * @function
       */
      getMainServerUrl: function() {
        return this.getDrupalSetting('mainServerURL');
      },

      /**
       * Returns WP plug-in version.
       *
       * @todo Replace with Kit version and drop it.
       *
       * @function
       */
      getPluginVersion: function() {
        return this.getDrupalSetting('version');
      },

      /**
       * @function
       */
      getAppId: function() {
        return this.getDrupalSetting('appId');
      },

      isAdmin: function() {
        return false;
      },

      /**
       * Returns parsed post data object.
       */
      getPostData: function() {
        if (typeof this.postData === 'undefined') {
          var content = $('meta[name="contextly-page"]').attr('content');
          if (content) {
            this.postData = easyXDM.getJSONObject().parse(content);
          }
          else {
            this.postData = {};
          }
        }

        return this.postData;
      },

      /**
       * Returns true on HTTPS protocol.
       */
      isHttps: function() {
        return this.getDrupalSetting('isHttps');
      },

      getDrupalCookieName: function() {
        return this.getDrupalSetting('cookieName', 'contextly');
      },

      /**
       * Returns visitor tracking cookie.
       *
       * @function
       */
      getCookieId: function() {
        var id = $.cookie(this.getDrupalCookieName());
        return id || null;
      },

      setDrupalCookieId: function(id) {
        // Make sure to store only non-empty value and keep previously set one.
        if (!id || this.getCookieId()) {
          return;
        }

        $.cookie(this.getDrupalCookieName(), id, {expires: 1, path: '/'});
      }

    }

  });

  /**
   * Loads settings of all page snippets on the node page and displays them.
   */
  Drupal.behaviors.contextlyWidgets = {
    attach: function (context, settings) {
      if (!settings.contextlyWidgets) {
        return;
      }

      // Make sure we initialize widgets only once on the page.
      var isFirstTime = $('body', context)
        .once('contextly-widgets')
        .length;
      if (!isFirstTime) {
        return;
      }

      // Get widget containers and make sure they're not empty.
      var containers = $('.ctx-module-container, .ctx-sidebar-container', context);
      if (!containers.length) {
        return;
      }

      var renderWidgets = function(widgets) {
        if (!widgets || !widgets.length) {
          return;
        }

        for (var i = 0; i < widgets.length; i++) {
          var widgetObject = Contextly.widget.Factory.getWidget(widgets[i]);
          if (widgetObject) {
            widgetObject.display();
          }
        }
      };

      var onSettingsLoadingSuccess = function(data) {
        // Set tracking cookie received from API server.
        Contextly.Settings.setDrupalCookieId(data.cookie_id);

        // Remove loading class.
        containers
          .removeClass('contextly-loading');

        // Render widgets.
        renderWidgets(data.entry.snippets);
        renderWidgets(data.entry.sidebars);

        // Send post update request to the server, if required.
        if (data.entry.update) {
          var nodeUpdateURL = Contextly.Settings.getDrupalNodeUpdateUrl();
          if (nodeUpdateURL) {
            $.ajax({
              url: nodeUpdateURL,
              type: 'POST',
              dataType: 'json'
            });
          }
        }
      };

      var onSettingsLoadingFailure = function() {
        containers
          .removeClass('contextly-loading')
          .addClass('contextly-error');
      };

      var loadSettings = function() {
        containers.addClass('contextly-loading');

        Contextly.RESTClient.call('pagewidgets', 'get', {}, function(response) {
          if (response && response.success && response.entry) {
            onSettingsLoadingSuccess(response);
          }
          else {
            onSettingsLoadingFailure();
          }
        });
      };

      loadSettings();
    }
  };

})(jQuery);

==> contextly-7.x-2.2.tar.gz: contextly/js/contextly-node-view.js <==
(function ($) {

  Contextly.Settings = Contextly.createClass({

    extend: Contextly.BaseSettings,

    statics: {

      /**
       * @param key
       * @param [fallback]
       */
      getDrupalSetting: function(key, fallback) {
        if (!Drupal.settings.contextlyWidgets) {
          return fallback;
        }

        if (typeof Drupal.settings.contextlyWidgets[key] === 'undefined') {
          return fallback;
        }

        return Drupal.settings.contextlyWidgets[key];
      },

      /**
       * Returns API server URL.
       *
       * @function
       */
      getAPIServerUrl: function() {
        return this.getDrupalSetting('apiServerURL');
      },

      /**
       * Returns main Contextly server URL.
       *
       * @function
       */
      getMainServerUrl: function() {
        return this.getDrupalSetting('mainServerURL');
      },

      /**
       * Returns WP plug-in version.
       *
       * @todo Replace with Kit version and drop it.
       *
       * @function
       */
      getPluginVersion: function() {
        return this.getDrupalSetting('version');
      },

      /**
       * @function
       */
      getAppId: function() {
        return this.getDrupalSetting('appId');
      }

    }

  });

  // Override page view method to control which widgets must be displayed.
  (function() {
    var original = Contextly.PageView.getDisplayableWidgetCollections;
    Contextly.PageView.getDisplayableWidgetCollections = function(response) {
      if (Contextly.Settings.getDrupalSetting('renderLinkWidgets')) {
        return original.apply(this, arguments);
      }
      else {
        // Still display storyline subscribe button on turned off link widgets.
        return [
          response.entry.storyline_subscribe
        ];
      }
    };
  })();

  /**
   * Loads settings of all page snippets on the node page and displays them.
   */
  Drupal.behaviors.contextlyWidgets = {
    attach: function (context, settings) {
      if (!settings.contextlyWidgets) {
        return;
      }

      // Make sure we initialize widgets only once on the page.
      var isFirstTime = $('body', context)
        .once('contextly-widgets')
        .length;
      if (!isFirstTime) {
        return;
      }

      // Get widget containers and make sure they exist.
      var containers = $('#ctx-module, .ctx-sidebar, #ctx-sl-subscribe', context);
      if (!containers.length) {
        return;
      }

      Contextly.load();
    }
  };

})(jQuery);
